# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

from tempest.scenario import manager


class DesignateScenarioTest(manager.ScenarioTest):

    credentials = ['primary', 'admin']
    headers = {'x-auth-all-projects': 'True'}

    @classmethod
    def setup_clients(cls):
        super(DesignateScenarioTest, cls).setup_clients()
        os_adm = getattr(cls, 'os_{}'.format(cls.credentials[1]))
        cls.zone_client = os_adm.dns_v2.ZonesClient(service='dns')
        cls.recordset_client = os_adm.dns_v2.RecordsetClient(service='dns')

    def get_zone_name_by_uuid(self, zone_id):
        _, zones = self.zone_client.list_zones(headers=self.headers)
        for zone in zones['zones']:
            if zone.get('id') == zone_id:
                return zone.get('name')

    def get_recordset_by_name(self, zone_id, recordset_name):
        _, recordsets = self.recordset_client.list_recordset(
            zone_id, headers=self.headers)
        for recordset in recordsets['recordsets']:
            if recordset.get('name') == recordset_name:
                return recordset
