# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.

import testtools

from designate_tempest_plugin.common import waiters
from designate_tempest_plugin.tests.scenario.v2 import designate_manager \
    as manager
from tempest import config
from tempest.lib import decorators
from tempest.lib.common.utils import data_utils

CONF = config.CONF


class TestServerIpsRecordset(manager.DesignateScenarioTest):

    build_timeout = CONF.dns.build_timeout

    @classmethod
    def skip_checks(cls):
        super(TestServerIpsRecordset, cls).skip_checks()
        if not CONF.dns.zone_id:
            raise cls.skipException(
                "Does not have zone_id")

    def setUp(self):
        super(TestServerIpsRecordset, self).setUp()
        self.server_name = 'test-dns-server-' + data_utils.rand_name()
        self.server = self.create_server(name=self.server_name,
                                         wait_until='ACTIVE')
        self.zone_id = CONF.dns.zone_id
        self.zone_name = self.get_zone_name_by_uuid(self.zone_id)

    def _get_server_fixed_ip(self, server):
        network = self.get_tenant_network()
        addresses = (server['addresses'][network['name']]
                     if network else [])
        for address in addresses:
            if (address['version'] == CONF.validation.ip_version_for_ssh
                    and address['OS-EXT-IPS:type'] == 'fixed'):
                return address['addr']

    @testtools.skipUnless(
        CONF.dns_feature_enabled.notification_nova_fixed,
        'The notification handlers for nova_fixed is disabled')
    @decorators.idempotent_id('d23f19a2-a3c9-49cc-9a6b-3a9b6830423f')
    def test_srever_fixed_ip_recordset(self):
        recordset_name = self.server_name + '.' + self.zone_name
        recordset = self.get_recordset_by_name(self.zone_id, recordset_name)
        waiters.wait_for_recordset_status(self.recordset_client, self.zone_id,
                                          recordset['id'], 'ACTIVE',
                                          headers=self.headers)
        fixed_ip = self._get_server_fixed_ip(self.server)
        self.assertEqual(fixed_ip, recordset['records'][0])

    @decorators.idempotent_id('57a7507f-e78d-4c60-877d-cd239602222c')
    @testtools.skipUnless(
        CONF.dns_feature_enabled.notification_neutron_floatingip,
        'The notification handlers for neutron_floatingip is disabled')
    def test_srever_floating_ip_recordset(self):
        floating_ip = self.create_floating_ip(self.server)['ip']
        recordset_floating_ip_name =\
            floating_ip.replace('.', '-') + '.' + self.zone_name
        recordset_floating_ip = self.get_recordset_by_name(
            self.zone_id, recordset_floating_ip_name)
        waiters.wait_for_recordset_status(self.recordset_client, self.zone_id,
                                          recordset_floating_ip['id'],
                                          'ACTIVE', headers=self.headers)
        self.assertEqual(floating_ip, recordset_floating_ip['records'][0])
